==> sqlitestudio-3.0.7.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translatorcomment>Interface GUI de SQLiteStudio un outil pour SQLite</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Messages de déboguage avec la console(accessible avec F12).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Messages de déboguage redirigés vers sortie standard(mode déboguage forcé).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation>Message de déboguage avec l&apos;analyseur Lemon pour un assistant code SQL.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation>Déboguage pour toutes requêtes SQL simple utilisé pour la plupart des bases de données.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translation>Limites des meesages de la requête SQL pour la &lt;database&gt;.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>database</source>
        <translation>Base de données</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translation>Listes des plugins installés dans SQLiteStudio et quitter.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>file</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Database file to open</source>
        <translation>Fichier de la base de données à ouvrir</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <location filename="../main.cpp" line="102"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
</TS>

==> sqlitestudio_3.1.0.orig.tar.gz: SQLiteStudio3/sqlitestudio/translations/sqlitestudio_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="44"/>
        <source>GUI interface to SQLiteStudio, a SQLite manager.</source>
        <translatorcomment>Interface GUI de SQLiteStudio un outil pour SQLite</translatorcomment>
        <translation></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Enables debug messages in console (accessible with F12).</source>
        <translation>Messages de déboguage avec la console(accessible avec F12).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Redirects debug messages into standard output (forces debug mode).</source>
        <translation>Messages de déboguage redirigés vers sortie standard(mode déboguage forcé).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Redirects debug messages into given file (forces debug mode).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>log file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Enables Lemon parser debug messages for SQL code assistant.</source>
        <translation>Message de déboguage avec l&rsquo;analyseur Lemon pour un assistant code SQL.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Enables debugging of every single SQL query being sent to any database.</source>
        <translation>Déboguage pour toutes requêtes SQL simple utilisé pour la plupart des bases de données.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Limits SQL query messages to only the given &lt;database&gt;.</source>
        <translation>Limites des meesages de la requête SQL pour la &lt;database&gt;.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>database</source>
        <translation>Base de données</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Lists plugins installed in the SQLiteStudio and quits.</source>
        <translation>Listes des plugins installés dans SQLiteStudio et quitter.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>file</source>
        <translation>Fichier</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Database file to open</source>
        <translation>Fichier de la base de données à ouvrir</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="86"/>
        <location filename="../main.cpp" line="102"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
</context>
</TS>
